'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

exports.default = getVueDoc;

var _variables = require('./variables');

var _processTags = require('./processTags');

var _processTags2 = _interopRequireDefault(_processTags);

var _processProps = require('./processProps');

var _processProps2 = _interopRequireDefault(_processProps);

var _processMethods = require('./processMethods');

var _processMethods2 = _interopRequireDefault(_processMethods);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var getFileName = function getFileName(fileName) {
	return fileName.split('\\').reverse()[0].split('.')[0];
};

var capitalizeFirstLetter = function capitalizeFirstLetter(str) {
	return str[0].toUpperCase() + str.substr(1);
};

var kebabToCamel = function kebabToCamel(myString) {
	return myString.replace(/-([aA-zZ])/g, function (g) {
		return g[1].toUpperCase();
	});
};

function getFileNameComponent(doc) {
	var packageComponent = doc.filter(function (comment) {
		return comment.kind === 'package';
	})[0];
	var fileName = packageComponent['files'][0];
	return capitalizeFirstLetter(kebabToCamel(getFileName(fileName)));
}

function getVueDoc(docFile, component) {
	try {
		var displayName = getFileNameComponent(docFile);
		docFile = docFile.filter(function (comment) {
			return comment.kind !== 'package';
		});
		var docComponent = docFile.filter(function (comment) {
			return comment.longname === 'module.exports';
		})[0];
		var description = (0, _variables.getDescription)(docComponent);
		var comment = (0, _variables.getComment)(docComponent);
		var tags = (0, _processTags2.default)(docComponent, ['name'].concat((0, _toConsumableArray3.default)(_variables.IGNORE_DEFAULT)));
		var props = (0, _processProps2.default)(docFile, component);
		var methods = (0, _processMethods2.default)(docFile, component);

		return {
			description: description,
			methods: methods,
			displayName: displayName,
			props: props,
			comment: comment,
			tags: tags
		};
	} catch (e) {
		console.log(e);
	}
}